@@ -29,9 +29,10 @@ GNSSDUMP_HELP = (
     + "gnssdump is a command line utility to stream the "
     + "parsed NMEA, UBX or RTCM3 output of a GNSS device to the terminal"
     + " or to designated NMEA, UBX or RTCM3 protocol handlers.\n\n"
-    + f"{GREEN}Usage (either stream, port or filename must be specified):{NORMAL}\n\n"
+    + f"{GREEN}Usage (either stream, port, socket or filename must be specified):{NORMAL}\n\n"
     + "  Serial stream: gnssdump port=/dev/ttyACM0 baudrate=9600 timeout=3, **kwargs\n"
     + "  File stream: gnssdump filename=gpslog.bin, **kwargs\n"
+    + "  Socket stream: gnssdump socket=192.168.0.72:50007, **kwargs\n"
     + "  Other stream object: gnssdump stream=stream, **kwargs\n"
     + "  Help: gnssdump -h\n\n"
     + f"{GREEN}Optional keyword arguments (default):{NORMAL}\n\n"
